<?php
$TRANSLATIONS = array(
"Expiration date is in the past." => "Aegumise kuupäev on minevikus.",
"Couldn't send mail to following users: %s " => "Kirja saatmine järgnevatele kasutajatele ebaõnnestus: %s ",
"Turned on maintenance mode" => "Haldusrežiimis sisse lülitatud",
"Turned off maintenance mode" => "Haldusrežiimis välja lülitatud",
"Updated database" => "Uuendatud andmebaas",
"Checked database schema update" => "Andmebaasi skeemi uuendus kontrollitud",
"Disabled incompatible apps: %s" => "Keelatud mitteühilduvad rakendid: %s",
"No image or file provided" => "Ühtegi pilti või faili pole pakutud",
"Unknown filetype" => "Tundmatu failitüüp",
"Invalid image" => "Vigane pilt",
"No temporary profile picture available, try again" => "Ühtegi ajutist profiili pilti pole saadaval, proovi uuesti",
"No crop data provided" => "Lõikeandmeid ei leitud",
"Sunday" => "Pühapäev",
"Monday" => "Esmaspäev",
"Tuesday" => "Teisipäev",
"Wednesday" => "Kolmapäev",
"Thursday" => "Neljapäev",
"Friday" => "Reede",
"Saturday" => "Laupäev",
"January" => "Jaanuar",
"February" => "Veebruar",
"March" => "Märts",
"April" => "Aprill",
"May" => "Mai",
"June" => "Juuni",
"July" => "Juuli",
"August" => "August",
"September" => "September",
"October" => "Oktoober",
"November" => "November",
"December" => "Detsember",
"Settings" => "Seaded",
"File" => "Fail",
"Folder" => "Kaust",
"Image" => "Pilt",
"Audio" => "Helid",
"Saving..." => "Salvestamine...",
"seconds ago" => "sekundit tagasi",
"_%n minute ago_::_%n minutes ago_" => array("%n minut tagasi","%n minutit tagasi"),
"_%n hour ago_::_%n hours ago_" => array("%n tund tagasi","%n tundi tagasi"),
"today" => "täna",
"yesterday" => "eile",
"_%n day ago_::_%n days ago_" => array("%n päev tagasi","%n päeva tagasi"),
"last month" => "viimasel kuul",
"_%n month ago_::_%n months ago_" => array("%n kuu tagasi","%n kuud tagasi"),
"last year" => "viimasel aastal",
"years ago" => "aastat tagasi",
"Couldn't send reset email. Please contact your administrator." => "Ei suutnud lähtestada e-maili. Palun kontakteeru süsteemihalduriga.",
"The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." => "Link parooli vahetuseks on saadetud Sinu e-posti aadressil.<br>Kui kiri pole saabunud mõistliku aja jooksul, siis kontrolli oma spam-/rämpskirjade katalooge<br>.Kui kirja pole ka seal, siis küsi abi süsteemihaldurilt.",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" => "Sinu failid on krüpteeritud. Kui sa pole taastamise võtit veel määranud, siis pole präast parooli taastamist mingit võimalust sinu andmeid tagasi saada. <br />Kui sa pole kindel, mida teha, siis palun väta enne jätkamist ühendust oma administaatoriga. <br />Oled sa kindel, et sa soovid jätkata?",
"I know what I'm doing" => "Ma tean mida teen",
"Reset password" => "Nulli parool",
"Password can not be changed. Please contact your administrator." => "Parooli ei saa muuta. Palun kontakteeru oma süsteemihalduriga.",
"Yes" => "Jah",
"No" => "Ei",
"Choose" => "Vali",
"Error loading file picker template: {error}" => "Viga failivalija malli laadimisel:  {error}",
"Ok" => "Ok",
"Error loading message template: {error}" => "Viga sõnumi malli laadimisel: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} failikonflikt","{count} failikonflikti"),
"One file conflict" => "Üks failikonflikt",
"New Files" => "Uued failid",
"Already existing files" => "Juba olemasolevad failid",
"Which files do you want to keep?" => "Milliseid faile sa soovid alles hoida?",
"If you select both versions, the copied file will have a number added to its name." => "Kui valid mõlemad versioonid, siis lisatakse kopeeritud faili nimele number.",
"Cancel" => "Loobu",
"Continue" => "Jätka",
"(all selected)" => "(kõik valitud)",
"({count} selected)" => "({count} valitud)",
"Error loading file exists template" => "Viga faili olemasolu malli laadimisel",
"Very weak password" => "Väga nõrk parool",
"Weak password" => "Nõrk parool",
"So-so password" => "Enam-vähem sobiv parool",
"Good password" => "Hea parool",
"Strong password" => "Väga hea parool",
"Shared" => "Jagatud",
"Shared by {owner}" => "Jagas {owner}",
"Shared with {recipients}" => "Jagatud {recipients}",
"Share" => "Jaga",
"Error" => "Viga",
"Error while sharing" => "Viga jagamisel",
"Error while unsharing" => "Viga jagamise lõpetamisel",
"Error while changing permissions" => "Viga õiguste muutmisel",
"Shared with you and the group {group} by {owner}" => "Jagatud sinu ja {group} grupiga {owner} poolt",
"Shared with you by {owner}" => "Sinuga jagas {owner}",
"Share with user or group …" => "Jaga kasutaja või grupiga ...",
"Share link" => "Jaga linki",
"The public link will expire no later than {days} days after it is created" => "Avalik link aegub mitte hiljem kui pärast {days} päeva selle loomist",
"By default the public link will expire after {days} days" => "Avalik link aegub vaikimisi pärast {days} päeva",
"Password protect" => "Parooliga kaitstud",
"Choose a password for the public link" => "Vali avaliku lingi jaoks parool",
"Allow Public Upload" => "Luba avalik üleslaadimine",
"Email link to person" => "Saada link isikule e-postiga",
"Send" => "Saada",
"Set expiration date" => "Määra aegumise kuupäev",
"Expiration date" => "Aegumise kuupäev",
"Share via email:" => "Jaga e-postiga:",
"No people found" => "Ühtegi inimest ei leitud",
"group" => "grupp",
"Resharing is not allowed" => "Edasijagamine pole lubatud",
"Shared in {item} with {user}" => "Jagatud {item} kasutajaga {user}",
"Unshare" => "Lõpeta jagamine",
"notify by email" => "teavita e-postiga",
"can share" => "saab jagada",
"can edit" => "saab muuta",
"access control" => "ligipääsukontroll",
"create" => "loo",
"update" => "uuenda",
"delete" => "kustuta",
"Password protected" => "Parooliga kaitstud",
"Error unsetting expiration date" => "Viga aegumise kuupäeva eemaldamisel",
"Error setting expiration date" => "Viga aegumise kuupäeva määramisel",
"Sending ..." => "Saatmine ...",
"Email sent" => "E-kiri on saadetud",
"Warning" => "Hoiatus",
"The object type is not specified." => "Objekti tüüp pole määratletud.",
"Enter new" => "Sisesta uus",
"Delete" => "Kustuta",
"Add" => "Lisa",
"Edit tags" => "Muuda silte",
"Error loading dialog template: {error}" => "Viga dialoogi malli laadimisel: {error}",
"No tags selected for deletion." => "Kustutamiseks pole ühtegi silti valitud.",
"Updating {productName} to version {version}, this may take a while." => "Uuendan {productName} versioonile {version}, see võtab veidi aega.",
"Please reload the page." => "Palun laadi see uuesti.",
"The update was unsuccessful." => "Uuendus ebaõnnestus.",
"The update was successful. Redirecting you to ownCloud now." => "Uuendus oli edukas. Kohe suunatakse Sind ownCloudi.",
"Couldn't reset password because the token is invalid" => "Ei saanud parooli taastada, kuna märgend on vigane",
"Couldn't send reset email. Please make sure your username is correct." => "Ei suutnud lähtestada e-maili. Palun veendu, et kasutajatunnus on õige.",
"Couldn't send reset email because there is no email address for this username. Please contact your administrator." => "Ei suutnud lähtestada e-maili, kuna sellel kasutajal pole e-posti määratud. Palun kontakteeru süsteemihalduriga.",
"%s password reset" => "%s parooli lähtestus",
"Use the following link to reset your password: {link}" => "Kasuta järgnevat linki oma parooli taastamiseks: {link}",
"You will receive a link to reset your password via Email." => "Sinu parooli taastamise link saadetakse sulle e-postile.",
"Username" => "Kasutajanimi",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" => "Sinu failid on krüpteeritud. Kui sa pole taastamise võtit veel määranud, siis pole präast parooli taastamist mingit võimalust sinu andmeid tagasi saada. Kui sa pole kindel, mida teha, siis palun väta enne jätkamist ühendust oma administaatoriga. Oled sa kindel, et sa soovid jätkata?",
"Yes, I really want to reset my password now" => "Jah, ma tõesti soovin oma parooli praegu taastada",
"Reset" => "Algseaded",
"New password" => "Uus parool",
"New Password" => "Uus parool",
"Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " => "Mac OS X ei ole toetatud ja %s ei pruugi korralikult toimida sellel platvormil. Kasuta seda omal vastutusel!",
"For the best results, please consider using a GNU/Linux server instead." => "Parema tulemuse saavitamiseks palun kaalu serveris GNU/Linux kasutamist.",
"Personal" => "Isiklik",
"Users" => "Kasutajad",
"Apps" => "Rakendused",
"Admin" => "Admin",
"Help" => "Abiinfo",
"Error loading tags" => "Viga siltide laadimisel",
"Tag already exists" => "Silt on juba olemas",
"Error deleting tag(s)" => "Viga sildi (siltide) kustutamisel",
"Error tagging" => "Viga sildi lisamisel",
"Error untagging" => "Viga sildi eemaldamisel",
"Error favoriting" => "Viga lemmikuks lisamisel",
"Error unfavoriting" => "Viga lemmikutest eemaldamisel",
"Access forbidden" => "Ligipääs on keelatud",
"Cloud not found" => "Pilve ei leitud",
"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "Tere,\n\n%s jagas sulle välja %s.\nVaata siit: %s\n\n",
"The share will expire on %s." => "Jagamine aegub %s.",
"Cheers!" => "Terekest!",
"Security Warning" => "Turvahoiatus",
"Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" => "Sinu PHP versioon on haavatav NULL Baidi (CVE-2006-7243) rünnakuga.",
"Please update your PHP installation to use %s securely." => "Palun uuenda oma paigaldatud PHP-d tagamaks %s turvalisus.",
"No secure random number generator is available, please enable the PHP OpenSSL extension." => "Turvalist juhuslike numbrite generaatorit pole saadaval. Palun luba PHP-s OpenSSL laiendus.",
"Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account." => "Ilma turvalise juhuslike numbrite generaatorita võib ründaja ennustada paroolivahetuse võtme ning hõivata su konto.",
"Your data directory and files are probably accessible from the internet because the .htaccess file does not work." => "Su andmete kataloog ja failid on tõenäoliselt internetist vabalt saadaval kuna .htaccess fail ei toimi.",
"For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." => "Serveri korrektseks seadistuseks palun tutvu <a href=\"%s\" target=\"_blank\">dokumentatsiooniga</a>.",
"Create an <strong>admin account</strong>" => "Loo <strong>admini konto</strong>",
"Password" => "Parool",
"Storage & database" => "Andmehoidla ja andmebaas",
"Data folder" => "Andmete kaust",
"Configure the database" => "Seadista andmebaasi",
"Only %s is available." => "Ainult %s on saadaval.",
"Database user" => "Andmebaasi kasutaja",
"Database password" => "Andmebaasi parool",
"Database name" => "Andmebasi nimi",
"Database tablespace" => "Andmebaasi tabeliruum",
"Database host" => "Andmebaasi host",
"SQLite will be used as database. For larger installations we recommend to change this." => "Andmebaasina kasutatakse SQLite-t. Suuremate paigalduste puhul me soovitame seda muuta.",
"Finish setup" => "Lõpeta seadistamine",
"Finishing …" => "Lõpetamine ...",
"This application requires JavaScript to be enabled for correct operation.  Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and re-load this interface." => "See rakendus vajab toimimiseks JavaScripti. Palun <a href=\"http://enable-javascript.com/\" target=\"_blank\">luba JavaScript</a> ning laadi see leht uuesti.",
"%s is available. Get more information on how to update." => "%s on saadaval. Vaata lähemalt kuidas uuendada.",
"Log out" => "Logi välja",
"Automatic logon rejected!" => "Automaatne sisselogimine lükati tagasi!",
"If you did not change your password recently, your account may be compromised!" => "Kui sa ei muutnud oma parooli hiljuti, siis võib su kasutajakonto olla ohustatud!",
"Please change your password to secure your account again." => "Palun muuda parooli, et oma kasutajakonto uuesti turvata.",
"Server side authentication failed!" => "Serveripoolne autentimine ebaõnnestus!",
"Please contact your administrator." => "Palun kontakteeru oma süsteemihalduriga.",
"Forgot your password? Reset it!" => "Unustasid parooli? Taasta see!",
"remember" => "pea meeles",
"Log in" => "Logi sisse",
"Alternative Logins" => "Alternatiivsed sisselogimisviisid",
"Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" => "Hei,<br><br>annan teada, et %s jagas sinuga <strong>%s</strong>. <a href=\"%s\">Vaata seda!</a><br><br>",
"This ownCloud instance is currently in single user mode." => "See ownCloud on momendil seadistatud ühe kasutaja jaoks.",
"This means only administrators can use the instance." => "See tähendab, et seda saavad kasutada ainult administraatorid.",
"Contact your system administrator if this message persists or appeared unexpectedly." => "Kontakteeru oma süsteemihalduriga, kui see teade püsib või on tekkinud ootamatult.",
"Thank you for your patience." => "Täname kannatlikkuse eest.",
"%s will be updated to version %s." => "%s uuendatakse versioonile %s.",
"The following apps will be disabled:" => "Järgnevad rakendid keelatakse:",
"The theme %s has been disabled." => "Teema %s on keelatud.",
"Please make sure that the database, the config folder and the data folder have been backed up before proceeding." => "Enne jätkamist veendu, et andmebaas, seadete ning andmete kataloog on varundatud.",
"Start update" => "Käivita uuendus",
"This ownCloud instance is currently being updated, which may take a while." => "Seda ownCloud instantsi hetkel uuendatakse, võib võtta veidi aega.",
"Please reload this page after a short time to continue using ownCloud." => "Palun laadi see leht uuesti veidi aja pärast jätkamaks ownCloud kasutamist.",
"To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" => "Suurtel saitidel aegumise vältimiseks võid sa paigalduskaustas käivitada järgmise käsu:",
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
